==> resin-4.0.27-src.tar.gz: resin-4.0.27/modules/resin/src/com/caucho/cloud/topology/TriadServer.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.cloud.topology;

import com.caucho.util.L10N;

/**
 * Defines a triad server, one of the three hub servers in a pod.
 */
public class TriadServer extends CloudServer {
  private static final L10N L = new L10N(TriadServer.class);

  public TriadServer(String id,
                     CloudPod pod, 
                     int index,
                     String address,
                     int port,
                     boolean isSSL,
                     CloudServer.ServerType isStatic,
                     boolean isAllowExternal)
  {
    super(id, pod, index, address, port, isSSL, isStatic, isAllowExternal);
    
    if (index < 0 || index > 2)
      throw new IllegalArgumentException(L.l("'{0}' is an invalid triad server index because it must be between 0 and 3",
                                            index));
  }

  /**
   * True if this server is a triad.
   */
  @Override
  public boolean isTriad()
  {
    return true;
  }
}

==> resin-4.0.52-src.tar.gz: resin-4.0.52/modules/resin/src/com/caucho/cloud/topology/TriadServer.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.cloud.topology;

import com.caucho.util.L10N;

/**
 * Defines a triad server, one of the three hub servers in a pod.
 */
public class TriadServer extends CloudServer {
  private static final L10N L = new L10N(TriadServer.class);

  public TriadServer(String id,
                     String displayId,
                     CloudPod pod, 
                     int index,
                     String address,
                     int port,
                     boolean isSSL,
                     CloudServer.ServerType isStatic,
                     boolean isAllowExternal)
  {
    super(id, displayId, pod, index, address, port, isSSL, isStatic, isAllowExternal);
    
    if (index < 0 || index > 2)
      throw new IllegalArgumentException(L.l("'{0}' is an invalid triad server index because it must be between 0 and 3",
                                            index));
  }

  /**
   * True if this server is a triad.
   */
  @Override
  public boolean isTriad()
  {
    return true;
  }
}
